Changelog
---------

- new MAJOR version for incompatible API changes,
- new MINOR version for added functionality in a backwards compatible manner
- new PATCH version for backwards compatible bug fixes

v1.0.3
---------
2023-01-13:
    - update github actions : checkout@v3 and setup-python@v4
    - remove "better code" badges
    - remove python 3.6 tests
    - add python 3.11 tests
    - update to pypy 3.9 tests

v1.0.2
--------
2022-05-20: update github actions test matrix to python 3.10

v1.0.1
--------
2022-03-29: remedy mypy Untyped decorator makes function "cli_info" untyped

v1.0.0
---------
2022-03-25: remove listdir of ./dist, moved to lib_cicd_github

v0.1.1
---------
2020-08-01: fix pypi deploy

v0.1.0
--------
2020-07-31:
    - change1
    - change2
    - ...
